==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.rt2.core/src/com/openexchange/office/rt2/core/doc/CopyDocumentInfo.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.rt2.core.doc;

import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.office.tools.error.ErrorCode;

//-------------------------------------------------------------------------
public class CopyDocumentInfo
{
    private ErrorCode aErrorCode;
    private String    sCopyFileID;
    private String    sCopyFolderID;
    private String    sCopyFileName;

    //-------------------------------------------------------------------------
    public CopyDocumentInfo(final ErrorCode errorCode)
    {
    	aErrorCode = errorCode;
    }

    //-------------------------------------------------------------------------
    public ErrorCode getErrorCode() { return aErrorCode; }

    //-------------------------------------------------------------------------
    public String    getFileID()    { return sCopyFileID; }

    //-------------------------------------------------------------------------
    public String    getFolderID()  { return sCopyFolderID; }

    //-------------------------------------------------------------------------
    public String    getFileName()  { return sCopyFileName; }

    //-------------------------------------------------------------------------
    public void setErrorCode(ErrorCode aErrorCode) { this.aErrorCode = aErrorCode; }

    //-------------------------------------------------------------------------
    public void setFileID(String sFileID)          { sCopyFileID = sFileID; }

    //-------------------------------------------------------------------------
    public void setFolderID(String sFolderID)      { sCopyFolderID = sFolderID; }

    //-------------------------------------------------------------------------
    public void setFileName(String sFileName)      { sCopyFileName = sFileName; }

    //-------------------------------------------------------------------------
    public JSONObject toJSON() throws JSONException
    {
        final JSONObject aJSON = new JSONObject();
        aJSON.put("filename" , getFileName());
        aJSON.put("folder_id", getFolderID());
        aJSON.put("id"       , getFileID());
        return aJSON;
    }
}

==> open-xchange-documents-backend_7.10.4.orig.tar.bz2: open-xchange-documents-backend-7.10.4/com.openexchange.office.rt2.core/src/com/openexchange/office/rt2/core/doc/CopyDocumentInfo.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.rt2.core.doc;

import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.office.tools.common.error.ErrorCode;

//-------------------------------------------------------------------------
public class CopyDocumentInfo
{
    private ErrorCode aErrorCode;
    private String    sCopyFileID;
    private String    sCopyFolderID;
    private String    sCopyFileName;

    //-------------------------------------------------------------------------
    public CopyDocumentInfo(final ErrorCode errorCode)
    {
    	aErrorCode = errorCode;
    }

    //-------------------------------------------------------------------------
    public ErrorCode getErrorCode() { return aErrorCode; }

    //-------------------------------------------------------------------------
    public String    getFileID()    { return sCopyFileID; }

    //-------------------------------------------------------------------------
    public String    getFolderID()  { return sCopyFolderID; }

    //-------------------------------------------------------------------------
    public String    getFileName()  { return sCopyFileName; }

    //-------------------------------------------------------------------------
    public void setErrorCode(ErrorCode aErrorCode) { this.aErrorCode = aErrorCode; }

    //-------------------------------------------------------------------------
    public void setFileID(String sFileID)          { sCopyFileID = sFileID; }

    //-------------------------------------------------------------------------
    public void setFolderID(String sFolderID)      { sCopyFolderID = sFolderID; }

    //-------------------------------------------------------------------------
    public void setFileName(String sFileName)      { sCopyFileName = sFileName; }

    //-------------------------------------------------------------------------
    public JSONObject toJSON() throws JSONException
    {
        final JSONObject aJSON = new JSONObject();
        aJSON.put("filename" , getFileName());
        aJSON.put("folder_id", getFolderID());
        aJSON.put("id"       , getFileID());
        return aJSON;
    }
}
